@@ -5,25 +5,25 @@ with 'MooseX::Clone';
 
 use overload ('""' => 'to_string');
 
+use Forest::Tree;
 use Graphics::Primitive::Border;
 use Graphics::Primitive::Insets;
 use Geometry::Primitive::Point;
 use Geometry::Primitive::Rectangle;
 
-use Forest::Tree;
-
 has 'background_color' => ( is => 'rw', isa => 'Graphics::Color');
 has 'border' => (
     is => 'rw',
     isa => 'Graphics::Primitive::Border',
-    default => sub { Graphics::Primitive::Border->new() }
+    default => sub { Graphics::Primitive::Border->new }
 );
 has 'color' => ( is => 'rw', isa => 'Graphics::Color');
 has 'height' => ( is => 'rw', isa => 'Num', default => sub { 0 } );
 has 'margins' => (
     is => 'rw',
     isa => 'Graphics::Primitive::Insets',
-    default => sub { Graphics::Primitive::Insets->new() }
+    default => sub { Graphics::Primitive::Insets->new },
+    coerce => 1
 );
 has 'name' => ( is => 'rw', isa => 'Str' );
 has 'origin' => (
@@ -34,7 +34,8 @@ has 'origin' => (
 has 'padding' => (
     is => 'rw',
     isa => 'Graphics::Primitive::Insets',
-    default => sub { Graphics::Primitive::Insets->new() }
+    default => sub { Graphics::Primitive::Insets->new },
+    coerce => 1
 );
 has 'page' => ( is => 'rw', isa => 'Bool', default => sub { 0 } );
 has 'maximum_height' => ( is => 'rw', isa => 'Num', default => sub { 0 } );
@@ -113,6 +114,8 @@ sub outside_width {
     my $w = $padding->left + $padding->right;
     $w += $margins->left + $margins->right;
     $w += $self->border->width * 2;
+
+    return $w;
 }
 
 sub outside_height {
@@ -124,6 +127,8 @@ sub outside_height {
     my $w = $padding->top + $padding->bottom;
     $w += $margins->top + $margins->bottom;
     $w += $self->border->width * 2;
+
+    return $w;
 }
 
 sub pack { }
@@ -131,8 +136,12 @@ sub pack { }
 sub prepare {
     my ($self, $driver) = @_;
 
-    $self->minimum_width($self->outside_width);
-    $self->minimum_height($self->outside_height);
+    unless($self->minimum_width) {
+        $self->minimum_width($self->outside_width);
+    }
+    unless($self->minimum_height) {
+        $self->minimum_height($self->outside_height);
+    }
 }
 
 sub to_string {
@@ -177,6 +186,8 @@ Most components do the majority of their setup in the B<prepare>.  The goal of
 prepare is to establish it's minimum height and width so that it can be
 properly positioned by a layout manager.
 
+  $driver->prepare($comp);
+
 =item B<layout>
 
 This is not a method of Component, but a phase introduced by the use of
@@ -187,6 +198,8 @@ manager implementations have different rules, so consult the documentation
 for each for details.  After this phase has completed the origin, height and
 width should be set for all components.
 
+  $lm->do_layout($comp);
+
 =item B<pack>
 
 This final phase provides and opportunity for the component to do any final
@@ -200,10 +213,14 @@ B<It is not ok to defer all action to the pack phase.  If you do not
 establish a minimum hieght and width during prepare then the layout manager
 may not provide you with enough space to draw.>
 
+    $driver->pack($comp);
+
 =item B<draw>
 
 Handled by L<Graphics::Primitive::Driver>.
 
+   $driver->draw($comp);
+
 =back
 
 =head1 METHODS
