@@ -1,6 +1,12 @@
 package Graphics::Primitive::Operation;
 use Moose;
 
+has 'preserve' => (
+    isa => 'Bool',
+    is  => 'rw',
+    default =>  sub { 0 },
+);
+
 __PACKAGE__->meta->make_immutable;
 
 no Moose;
@@ -16,6 +22,17 @@ is an action that is performed on a path such as a
 L<Fill|Graphics::Primitive::Operation::Fill> or
 L<Fill|Graphics::Primitive::Operation::Stroke>.
 
+=head1 METHODS
+
+=over 4
+
+=item I<preserve>
+
+Informs the canvas to not clear the current path when performing this
+operation.  Also provides a hint to the driver.
+
+=back
+
 =head1 AUTHOR
 
 Cory Watson <gphat@cpan.org>
